import React, { useCallback, useState } from 'react';
import { useFocusEffect } from '@react-navigation/native';
import { Header, PageWrapper } from '../../../../components';
import { getOnlineStatus, storage, StoreType } from '../../../../storage';

import { Profile } from '../Components/Profile';

import { Ranking } from '../Ranking';
import { FlatList } from 'react-native';
import { fetchFullRanking } from '@api/ranking';

const MasterRankingScreen = () => {
  const [masterRanking, setMasterRanking] = useState<Ranking[]>([]);
  const { mutateAsync } = fetchFullRanking();
  const [isLoading, setIsLoading] = useState(true);

  useFocusEffect(
    useCallback(() => {
      const fetchRanking = async () => {
        const ranking = storage.get('masterRanking', StoreType.STRING) as string;
        setMasterRanking(JSON.parse(ranking).sort((a: Ranking, b: Ranking) => b.score_nm - a.score_nm));
        setIsLoading(false);
      };

      fetchRanking();
    }, [])
  );

  if (isLoading) {
    return null;
  }

  const getFullRanking = async () => {
    if (getOnlineStatus()) {
      await mutateAsync(undefined, {
        onSuccess: (data) => {
          setMasterRanking(data.data);
        }
      });
    }
  };

  return (
    <PageWrapper>
      <FlatList
        showsVerticalScrollIndicator={false}
        data={masterRanking}
        ListHeaderComponent={<Header label="Master Ranking" />}
        keyExtractor={(item) => item.user_id.toString()}
        renderItem={({ item, index }) => (
          <Profile
            key={index}
            index={index}
            first_name={item.first_name}
            last_name={item.last_name}
            avatar={item.avatar}
            date_of_birth={item.age}
            homebase_flag={item.flag1}
            homebase2_flag={item.flag2}
            score={[
              item.score_nm,
              item.score_dare,
              item.score_un,
              item.score_unp,
              item.score_tcc,
              item.score_yes,
              item.score_slow,
              item.score_whs,
              item.score_kye
            ]}
            tbt_score={item.score_tbt}
            tbt_rank={item.rank_tbt}
            badge_tbt={item.badge_tbt}
            badge_1281={item.badge_1281}
            badge_un={item.badge_un}
            auth={item.auth}
          />
        )}
        onEndReached={() => getFullRanking()}
        onEndReachedThreshold={0.5}
      />
    </PageWrapper>
  );
};

export default MasterRankingScreen;
